<?php
/**
 * [Short description]
 *
 * @package DEVRY
 * @subpackage DEVELOPRY_X
 * @since 1.0
 */
namespace DEVRY\DEVELOPRY_X;

! defined( ABSPATH ) || exit; // Exit if accessed directly.

/**
 * Attach/configure font family stylesheets option in WP Customizer > Theme Options.
 */
function add_custom_font( $wp_customize ) {
	/**
	 * Theme font family option added to WP Customizer > Theme Options
	 */
	class Custom_Font extends \WP_Customize_Control {
		/**
		 * WP Customizer field type.
		 */
		public $type = 'select';

		/**
		 * Print out the custom option HTML structure.
		 */
		public function render_content() {
			$option = $this->value();
			?>
			<label class="customize-control-title">
				<?php echo esc_html( $this->label ); ?>
			</label>
			<select class="customize-control" <?php $this->link(); ?>>
				<option value="Montserrat" <?php echo ( 'Montserrat' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Montserrat (default)', 'developry-x' ); ?>
				</option>
				<option value="">--</option>
				<option value="Fira Mono" <?php echo ( 'Fira Mono' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Fira Mono', 'developry-x' ); ?>
				</option>
				<option value="Inconsolata" <?php echo ( 'Inconsolata' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Inconsolata', 'developry-x' ); ?>
				</option>
				<option value="Lato" <?php echo ( 'Lato' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Lato', 'developry-x' ); ?>
				</option>
				<option value="Merriweather" <?php echo ( 'Merriweather' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Merriweather', 'developry-x' ); ?>
				</option>
				<option value="PT Sans" <?php echo ( 'PT Sans' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'PT Sans', 'developry-x' ); ?>
				</option>
				<option value="PT Serif" <?php echo ( 'PT Serif' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'PT Serif', 'developry-x' ); ?>
				</option>
				<option value="Raleway" <?php echo ( 'Raleway' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Raleway', 'developry-x' ); ?>
				</option>
				<option value="Roboto" <?php echo ( 'Roboto' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Roboto', 'developry-x' ); ?>
				</option>
				<option value="Ubuntu" <?php echo ( 'Ubuntu' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Ubuntu', 'developry-x' ); ?>
				</option>
			</select>
			<br clear="all" />
			<p class="customize-control-description developry-x-customizer-control-description">
				<?php echo esc_html( $this->description ); ?>
			</p>
			<?php
		}
	}

	$wp_customize->selective_refresh->add_partial( 'developry_x_theme_options_custom_font' );

	$wp_customize->add_setting(
		'developry_x_theme_options[custom_font]',
		array(
			'default'           => 'Montserrat',
			'sanitize_callback' => 'esc_attr',
			'transport'         => 'postMessage',
			'capability'        => 'edit_theme_options',
		)
	);

	$wp_customize->add_control(
		new Custom_Font(
			$wp_customize,
			'developry_x_theme[custom_font]',
			array(
				'label'       => esc_html__( 'Custom Font', 'developry-x' ),
				'description' => esc_html__( 'Change website font from the Google Fonts library.', 'developry-x' ),
				'section'     => 'developry_x_theme_options',
				'settings'    => 'developry_x_theme_options[custom_font]',
			)
		)
	);
}

add_action( 'customize_register', __NAMESPACE__ . '\add_custom_font' );
