<?php
/**
 * [Short description]
 *
 * @package DEVRY
 * @subpackage DEVELOPRY_X
 * @since 1.0
 */
namespace DEVRY\DEVELOPRY_X;

! defined( ABSPATH ) || exit; // Exit if accessed directly.

/**
 * Attach/configure custom theme stylesheets options in WP Customizer > Theme Options.
 */
function add_custom_theme( $wp_customize ) {
	/**
	 * Theme custom theme options added to WP Customizer > Theme Options
	 */
	class Custom_Theme extends \WP_Customize_Control {
		/**
		 * WP Customizer field type.
		 */
		public $type = 'select';

		/**
		 * Print out the custom option HTML structure.
		 */
		public function render_content() {
			$option = $this->value();
			?>
			<label class="customize-control-title">
				<?php echo esc_html( $this->label ); ?>
			</label>
			<select class="customize-control" <?php $this->link(); ?>>
				<option value="cyan" <?php echo ( 'cyan' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Cyan (default)', 'developry-x' ); ?>
				</option>
				<option value="cyan">--</option>
				<option value="brown" <?php echo ( 'brown' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Brown', 'developry-x' ); ?>
				</option>
				<option value="blue-grey" <?php echo ( 'blue-grey' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Blue Grey', 'developry-x' ); ?>
				</option>
				<option value="emerald" <?php echo ( 'emerald' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Emerald', 'developry-x' ); ?>
				</option>
				<option value="indigo" <?php echo ( 'indigo' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Indigo', 'developry-x' ); ?>
				</option>
				<option value="lime" <?php echo ( 'lime' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Lime', 'developry-x' ); ?>
				</option>
				<option value="orange" <?php echo ( 'orange' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Orange', 'developry-x' ); ?>
				</option>
				<option value="pink" <?php echo ( 'pink' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Pink', 'developry-x' ); ?>
				</option>
				<option value="red" <?php echo ( 'red' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Red', 'developry-x' ); ?>
				</option>
				<option value="teal" <?php echo ( 'teal' === $option ) ? 'selected' : ''; ?>>
					<?php echo esc_html__( 'Teal', 'developry-x' ); ?>
				</option>
			</select>
			<br clear="all" />
			<p class="customize-control-description developry-x-customizer-control-description">
				<?php echo esc_html( $this->description ); ?>
			</p>
			<?php
		}
	}

	$wp_customize->selective_refresh->add_partial( 'developry_x_theme_options_custom_theme' );

	$wp_customize->add_setting(
		'developry_x_theme_options[custom_theme]',
		array(
			'default'           => 'cyan',
			'sanitize_callback' => 'esc_attr',
			'transport'         => 'postMessage',
			'capability'        => 'edit_theme_options',
		)
	);

	$wp_customize->add_control(
		new Custom_Theme(
			$wp_customize,
			'developry_x_theme[custom_theme]',
			array(
				'label'       => esc_html__( 'Custom Theme', 'developry-x' ),
				'description' => esc_html__( 'Change the default look of your website by selecting one of the themes above.', 'developry-x' ),
				'section'     => 'developry_x_theme_options',
				'settings'    => 'developry_x_theme_options[custom_theme]',
			)
		)
	);
}

add_action( 'customize_register', __NAMESPACE__ . '\add_custom_theme' );
