<?php
/**
 * Load stylesheets for our theme's front-end.
 *
 * @package DEVRY
 * @subpackage DEVELOPRY_X
 * @since 1.0
 */
namespace DEVRY\DEVELOPRY_X;

! defined( ABSPATH ) || exit; // Exit if accessed directly.

if ( ! function_exists( 'wp_enqueue_style' ) ) {
	return;
}

/**
 * Equeue theme stylesheets.
 */
function enqueue_theme_styles() {
	$theme_version = wp_get_theme()->get( 'Version' );

	// Check if Dashicons are already enqueued.
	if ( ! wp_script_is( 'dashicons', 'enqueued' ) ) {
		wp_enqueue_style( 'dashicons' );
	}

	// Enqueue the theme custom CSS file(s). Based on WP Customzier selection by user.
	$theme_options = (array) json_decode( DEVELOPRY_X_THEME_OPTIONS );

	if ( ! empty( $theme_options['custom_theme'] ) ) {
		wp_enqueue_style(
			'developry-x',
			DEVELOPRY_X_THEME_URI . '/assets/dist/css/themes/' . $theme_options['custom_theme'] . '.min.css',
			array(),
			$theme_version
		);
	} else {
		// Enqueue the default library CSS file in case the option is empty.
		// Enqueue the theme main style.css file.
		wp_enqueue_style(
			'developry-x',
			get_stylesheet_uri(),
			array(),
			$theme_version
		);
	}

	if ( ! empty( $theme_options['custom_font'] ) ) {
		wp_enqueue_style(
			'developry-x-custom-font-family',
			"https://fonts.googleapis.com/css?family={$theme_options['custom_font']}:wght@400,700&display=swap",
			array(),
			$theme_version
		);

		wp_add_inline_style(
			'developry-x',
			"body { font-family: '{$theme_options['custom_font']}', Droid Sans, Helvetica Neue, Helvetica, Arial, -apple-system, BlinkMacSystemFont, sans-serif !important; }"
		);
	} else {
		wp_enqueue_style(
			'developry-x-custom-font-family',
			'https://fonts.googleapis.com/css?family=Montserrat:400,700&display=swap',
			array(),
			$theme_version
		);
	}
}

add_action( 'wp_enqueue_scripts', __NAMESPACE__ . '\enqueue_theme_styles' );
